# CMF imports
from Products.CMFCore import permissions

# Archetypes imports
from Products.Archetypes import atapi

# Product imports
from Products.EntitiesDirectory.config import PROJECTNAME


# Schema definition
schema = atapi.BaseSchema.copy() +  atapi.Schema((

    atapi.TextField('slogan',
              searchable = 1,
              required = 1,
              storage = atapi.AttributeStorage(),
              widget=atapi.TextAreaWidget(description="Slogan", label="Slogan"),
              #storage = atapi.AnnotationStorage(), # PREGUNTAR
              ),
    atapi.ImageField('image',
              max_size = (768,768),
              languageIndependent = True,
              storage = atapi.AttributeStorage(),
              #storage = atapi.AnnotationStorage(),
              sizes= {'large'   : (768, 768),
                'preview' : (400, 400),
                'mini'    : (200, 200),
                'thumb'   : (128, 128),
                'tile'    :  (64, 64),
                'icon'    :  (32, 32),
                'listing' :  (16, 16),
               },        
              ),            
    atapi.TextField('text',
              searchable = 1,
              required = 1,
              #storage = AnnotationStorage(), # PREGUNTAR
              validators = ('isTidyHtmlWithCleanup',),
              allowable_content_types = ('text/plain',
                                       'text/structured',
                                       'text/html',),
              default_output_type = 'text/x-html-safe',
              widget = atapi.RichWidget(label = 'Text'),       
              ),
    atapi.StringField('webSite',
              validators = ('isURL',),
              ),
    atapi.StringField('email',
                validators = ('isEmail',),
                ),
    atapi.StringField('phone',
              maxlength = 20,
              size = 20,
              ),
    atapi.StringField('mobile',
              maxlength = 20,
              size = 20,
              ),
    atapi.StringField('fax',
              maxlength = 20,
              size = 20,
              ),
    atapi.StringField('address',
              required = True,
              ),
    atapi.StringField('zip',
              maxlength = 9,
              size = 9,
              ),
    atapi.StringField('city',
              searchable = 1,
              required = 1,
              ),
    atapi.StringField('province',
              searchable = 1,
              required = 1,
              ),
    atapi.StringField('country',
              searchable = 1,
              required = 1,
              ),
    atapi.StringField('territorialScope',
              searchable = 1,
              required = 1,
              ),
    atapi.StringField('topics',
              searchable = 1,
              required = 1,
              ),
    # NameError: name 'ReferenceBrowserWidget' is not defined
    #atapi.ReferenceField('references',
    #          widget = atapi.ReferenceBrowserWidget(),
    #          multiValued = True,
    #          ),
    ))


class EntitiesDirectory(atapi.BaseContent):
    """An Archetype for an EntitiesDirectory application"""

    schema = schema

    meta_type = portal_type = 'EntitiesDirectory'
    archetype_name = 'Entities Directory'
    
    _at_rename_after_creation = True
    
    actions = ({
        'id'          : 'view',
        'name'        : 'View',
        'action'      : 'string:${object_url}',
        'permissions' : (permissions.View,)
         },
        {
        'id'          : 'edit',
        'name'        : 'Edit',
        'action'      : 'string:${object_url}/edit',
        'permissions' : (permissions.ModifyPortalContent,),
         },
        {
        'id'          : 'metadata',
        'name'        : 'Properties',
        'action'      : 'string:${object_url}/properties',
        'permissions' : (permissions.ModifyPortalContent,),
         },
        )

    aliases = {
        '(Default)'  : 'entitiesdirectory_view',
        'view'       : 'entitiesdirectory_view',
        'edit'       : 'base_edit',
        'properties' : 'base_metadata',
        }
    
    def getObfuscatedEmail(self):
        """Get a modified version of email so spambots can't read it.
        """
        email = self.getEmail()
        obfuscated_email = email.replace('@', '-antispam-')
        return obfuscated_email + '@$%&.com'
    
    def tag(self, **kwargs):
        return self.getField('image').tag(self, **kwargs)

atapi.registerType(EntitiesDirectory, PROJECTNAME)
